@@ -224,7 +224,7 @@ def cmd_git(path=None, url=None, branch='master', tag=None, user=None):
                     cmd_su("cd %s && git checkout %s" % (path,branch), user)
 
 
-        cmd_su("cd %s && git pull origin %s" % (path,branch), user)
+        cmd_su("cd %s && git pull origin %s --tags" % (path,branch), user)
         if tag:
             cmd_su("cd %s && git checkout %s" % (path,tag), user)
 
@@ -245,3 +245,13 @@ def cmd_ip(card='eth0'):
 
 
 
+def cmd_write_str(file,data):
+
+    with settings(warn_only=True):
+
+
+        pass
+
+
+    pass
+
